@@ -1,6 +1,6 @@
 package Ubic::Run;
 BEGIN {
-  $Ubic::Run::VERSION = '1.18';
+  $Ubic::Run::VERSION = '1.19';
 }
 
 use strict;
@@ -15,13 +15,13 @@ use Pod::Usage;
 
 sub import {
     my $name;
-    if ( $0 =~ qr{^/etc/init\.d/(.+)$} ) {
+    if ( $0 =~ m{^/etc/init\.d/(.+)$} ) {
         $name = $1;
     }
-    elsif ( $0 =~ qr{^/etc/rc\d\.d/(?:K|S)\d+(.+)$} ) {
+    elsif ( $0 =~ m{^/etc/rc\d\.d/(?:K|S)\d+(.+)$} ) {
         $name = $1;
     }
-    elsif ( $0 =~ qr{^/etc/rc\.d/init\.d/(.+)$} ) {
+    elsif ( $0 =~ m{^/etc/rc\.d/init\.d/(.+)$} ) {
         $name = $1;
     }
     else {
@@ -60,7 +60,7 @@ Ubic::Run - really simple way to write init scripts
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -73,11 +73,11 @@ This module allows to represent any ubic service as an init script.
 
 It resolves service name automatically by looking at process C<$0>.
 
-Currently, it supports systems where init script is located at C</etc/init.d/> (LSB-compatible systems as specified by L<http://refspecs.freestandards.org/LSB_4.0.0/LSB-Core-generic/LSB-Core-generic/initsrcinstrm.html>, for example, Debian and Ubuntu), or on systems where this directory is called C</etc/rc.d/init.d/> (for example, RedHat).
+Currently, it supports systems where init script is located at C</etc/init.d/> (LSB-compatible systems as specified by L<http://refspecs.freestandards.org/LSB_4.0.0/LSB-Core-generic/LSB-Core-generic/initsrcinstrm.html>, for example, Debian and Ubuntu) and systems where this directory is called C</etc/rc.d/init.d/> (for example, RedHat).
 
 =head1 BUGS AND CAVEATS
 
-Some *nix distributions can use different places for init scripts. If your system doesn't conform to cases listed in description, this module will have to be patched.
+*nix distributions can use different places for init scripts. If your system doesn't conform to cases listed in description, this module will have to be patched.
 
 Note that you usually don't want to use SysV-style rcX.d runlevel symlinks, because Ubic remembers if service should be running by other means (by storing status files in C</var/lib/ubic/status/>), L<ubic-watchdog> brings all enabled services up in one minute after reboot, and usually it's all you need anyway. If this bothers you, please remind me about it - I know a way to fix it (by adding additional abstraction layer which stores statuses), but I don't think I'll do this before anyone will actually care.
 
